@@ -108,7 +108,7 @@ macro_rules! describe_type (
             data: $crate::ModelData::Single($crate::ModelType {
                 nullable: false,
                 type_description: $crate::ModelTypeDescription::Array($crate::ModelArray {
-                    items: Box::new(describe_type!(@object_property_value $($property_tail)*))
+                    items: Box::new($crate::describe_type!(@object_property_value $($property_tail)*))
                 })
             })
         }
@@ -124,7 +124,7 @@ macro_rules! describe_type (
         #[allow(unused_mut)]
         let mut required = Vec::new();
 
-        $(describe_type!(@object_property [properties, required] $property_name$([$required])?: ($($property_tail)*)));*;
+        $($crate::describe_type!(@object_property [properties, required] $property_name$([$required])?: ($($property_tail)*)));*;
 
         $crate::Model {
             description: $crate::macros::FromStrangeTuple::extract(($($description.to_string(),)?)),
@@ -140,12 +140,12 @@ macro_rules! describe_type (
     }};
 
     (@object_property [$properties:ident, $required:ident] $property_name:ident: ($($property_tail:tt)*)) => {
-        $properties.insert(stringify!($property_name).to_string(), describe_type!(@object_property_value $($property_tail)*));
+        $properties.insert(stringify!($property_name).to_string(), $crate::describe_type!(@object_property_value $($property_tail)*));
     };
 
 
     (@object_property [$properties:ident, $required:ident] $property_name:ident[required]: ($($property_tail:tt)*)) => {
-        describe_type!(@object_property [$properties, $required] $property_name: ($($property_tail)*));
+        $crate::describe_type!(@object_property [$properties, $required] $property_name: ($($property_tail)*));
         $required.push(stringify!($property_name).to_owned());
     };
 
@@ -158,7 +158,7 @@ macro_rules! describe_type (
     };
 
     (@object_property_value $type:ident => $($tail:tt)*) => {
-        $crate::ModelReference::Inline(describe_type!($type => $($tail)*))
+        $crate::ModelReference::Inline($crate::describe_type!($type => $($tail)*))
     }
 );
 
@@ -177,7 +177,7 @@ macro_rules! impl_opg_model (
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
                 <T as $crate::OpgModel>::type_name()
             }
         }
@@ -193,7 +193,7 @@ macro_rules! impl_opg_model (
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
                 <T as $crate::OpgModel>::type_name()
             }
         }
@@ -214,19 +214,19 @@ macro_rules! impl_opg_model (
                     }),
                 };
 
-                describe_type!(array => {
+                $crate::describe_type!(array => {
                     items: (raw_model => item_model)
                 })
             }
 
             #[inline]
-            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
-                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
+                None
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
-                None
+            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
+                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
             }
         }
     };
@@ -250,13 +250,13 @@ macro_rules! impl_opg_model (
             }
 
             #[inline]
-            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
-                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
+                None
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
-                None
+            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
+                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
             }
         }
     };
@@ -281,13 +281,13 @@ macro_rules! impl_opg_model (
             }
 
             #[inline]
-            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
-                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
+                None
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
-                None
+            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
+                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
             }
         }
     };
@@ -295,13 +295,13 @@ macro_rules! impl_opg_model (
     ($serialized_type:ident$(($format:literal))?: $($type:tt)+ ) => {
         impl $crate::OpgModel for $($type)+ {
             fn get_schema(cx: &mut $crate::Components) -> Model {
-                describe_type!($serialized_type => {
+                $crate::describe_type!($serialized_type => {
                     $(format: $format)?
                 })
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
                 <T as $crate::OpgModel>::type_name()
             }
         }
@@ -310,19 +310,19 @@ macro_rules! impl_opg_model (
     ($serialized_type:ident(always_inline$(, $format:literal)?): $($type:tt)+) => {
         impl $crate::OpgModel for $($type)+ {
             fn get_schema(_: &mut $crate::Components) -> Model {
-                describe_type!($serialized_type => {
+                $crate::describe_type!($serialized_type => {
                     $(format: $format)?
                 })
             }
 
             #[inline]
-            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
-                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
+            fn type_name() -> Option<std::borrow::Cow<'static, str>> {
+                None
             }
 
             #[inline]
-            fn type_name() -> Option<&'static str> {
-                None
+            fn select_reference(cx: &mut $crate::Components, _: bool, params: &$crate::ContextParams) -> $crate::ModelReference {
+                $crate::ModelReference::Inline(Self::get_schema(cx).apply_params(params))
             }
         }
     };
@@ -332,13 +332,13 @@ macro_rules! impl_opg_model (
 macro_rules! describe_api {
     ($($property:ident: {$($property_value:tt)*}),*$(,)?) => {{
         let mut result = $crate::models::Opg::default();
-        $(describe_api!(@opg_property result $property $($property_value)*));+;
+        $($crate::describe_api!(@opg_property result $property $($property_value)*));+;
         result
     }};
 
 
     (@opg_property $result:ident info $($property:ident: $property_value:expr),*$(,)?) => {{
-        $(let $property = describe_api!(@opg_info_property $property $property_value));*;
+        $(let $property = $crate::describe_api!(@opg_info_property $property $property_value));*;
         $result.info = $crate::models::Info {
             $($property,)*
             ..Default::default()
@@ -349,27 +349,29 @@ macro_rules! describe_api {
     (@opg_info_property description $value:expr) => { Some(($value).to_string()) };
 
 
-    (@opg_property $result:ident tags $($tag:ident$(($description:literal))?),*$(,)?) => {{
+    (@opg_property $result:ident tags $($tag:ident$(($description:expr))?),*$(,)?) => {{
         $($result.tags.insert(stringify!($tag).to_owned(), $crate::models::Tag {
-            description: $crate::macros::FromStrangeTuple::extract(($($description.to_string(),)?)),
+            description: $crate::macros::FromStrangeTuple::extract(($(($description).to_string(),)?)),
         }));*;
     }};
 
 
-    (@opg_property $result:ident servers $($url:literal$(($description:literal))?),*$(,)?) => {{
+    (@opg_property $result:ident servers $($url:tt$(($description:tt))?),*$(,)?) => {{
         $($result.servers.push($crate::models::Server {
-            url: $url.to_owned(),
-            description: $crate::macros::FromStrangeTuple::extract(($($description.to_owned(),)?)),
+            url: $crate::describe_api!(@opg_property_server_literal $url),
+            description: $crate::macros::FromStrangeTuple::extract(($($crate::describe_api!(@opg_property_server_literal $description),)?)),
         }));*;
     }};
+    (@opg_property_server_literal $l:literal) => { $l.to_owned() };
+    (@opg_property_server_literal $l:ident) => { $l.into() };
 
 
     (@opg_property $result:ident security_schemes $($schemes:tt)*) => {
-        describe_api!(@opg_security_scheme $result $($schemes)*,)
+        $crate::describe_api!(@opg_security_scheme $result $($schemes)*,)
     };
     (@opg_security_scheme $result:ident $scheme:ident, $($other:tt)*) => {
         $result.components.security_schemes.insert(stringity!($scheme).to_owned(), $scheme);
-        describe_api!(@opg_security_scheme $result $($other)*)
+        $crate::describe_api!(@opg_security_scheme $result $($other)*)
     };
     (@opg_security_scheme $result:ident (http $name:literal): {$($properties:tt)+}, $($other:tt)*) => {
         {
@@ -377,7 +379,7 @@ macro_rules! describe_api {
             let mut bearer_format: Option<String> = None;
             let mut description: Option<String> = None;
 
-            describe_api!(@opg_security_scheme_http scheme bearer_format description $($properties)*,);
+            $crate::describe_api!(@opg_security_scheme_http scheme bearer_format description $($properties)*,);
 
             let http_security_scheme = match scheme {
                 $crate::HttpSecuritySchemeKind::Basic => $crate::models::HttpSecurityScheme::Basic {
@@ -391,15 +393,15 @@ macro_rules! describe_api {
 
             $result.components.security_schemes.insert($name.to_owned(), $crate::models::SecurityScheme::Http(http_security_scheme));
         };
-        describe_api!(@opg_security_scheme $result $($other)*)
+        $crate::describe_api!(@opg_security_scheme $result $($other)*)
     };
-    (@opg_security_scheme $result:ident (apiKey $name:literal): {$($properties:tt)+}, $($other:tt)*) => {
+    (@opg_security_scheme $result:ident (apiKey $name:expr): {$($properties:tt)+}, $($other:tt)*) => {
         {
             let mut parameter_in = $crate::models::ParameterIn::Header;
             let name = $crate::models::ParameterNotSpecified;
             let mut description: Option<String> = None;
 
-            describe_api!(@opg_security_scheme_api_key parameter_in name description $($properties)*,);
+            $crate::describe_api!(@opg_security_scheme_api_key parameter_in name description $($properties)*,);
 
             let scheme = $crate::models::ApiKeySecurityScheme {
                 parameter_in,
@@ -407,39 +409,39 @@ macro_rules! describe_api {
                 description,
             };
 
-            $result.components.security_schemes.insert($name.to_owned(), $crate::models::SecurityScheme::ApiKey(scheme));
+            $result.components.security_schemes.insert(($name).to_string(), $crate::models::SecurityScheme::ApiKey(scheme));
         };
-        describe_api!(@opg_security_scheme $result $($other)*)
+        $crate::describe_api!(@opg_security_scheme $result $($other)*)
     };
     (@opg_security_scheme $result:ident $(,)?) => {};
 
 
     (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident scheme: $value:ident, $($other:tt)*) => {
         let $scheme = $crate::models::HttpSecuritySchemeKind::$value;
-        describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
+        $crate::describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
     };
-    (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident bearer_format: $value:literal, $($other:tt)*) => {
-        $bearer_format = Some($value.to_owned());
-        describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
+    (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident bearer_format: $value:expr, $($other:tt)*) => {
+        $bearer_format = Some(($value).to_string());
+        $crate::describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
     };
-    (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident description: $value:literal, $($other:tt)*) => {
-        $description = Some($value.to_owned());
-        describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
+    (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident description: $value:expr, $($other:tt)*) => {
+        $description = Some(($value).to_string());
+        $crate::describe_api!(@opg_security_scheme_http $scheme $bearer_format $description $($other)*)
     };
     (@opg_security_scheme_http $scheme:ident $bearer_format:ident $description:ident $(,)?) => {};
 
 
     (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident parameter_in: $value:ident, $($other:tt)*) => {
         $parameter_in = $crate::models::ParameterIn::$value;
-        describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
+        $crate::describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
     };
-    (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident name: $value:literal, $($other:tt)*) => {
-        let $name = $value.to_owned();
-        describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
+    (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident name: $value:expr, $($other:tt)*) => {
+        let $name = ($value).to_string();
+        $crate::describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
     };
-    (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident description: $value:literal, $($other:tt)*) => {
-        $description = Some($value.to_owned());
-        describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
+    (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident description: $value:expr, $($other:tt)*) => {
+        $description = Some(($value).to_string());
+        $crate::describe_api!(@opg_security_scheme_api_key $parameter_in $name $description $($other)*)
     };
     (@opg_security_scheme_api_key $parameter_in:ident $name:ident $description:ident $(,)?) => {};
 
@@ -451,82 +453,82 @@ macro_rules! describe_api {
             let mut path = Vec::new();
             let mut context = $crate::models::PathValue::default();
 
-            describe_api!(@opg_property_url path $result context { $($path_segment)* });
-            describe_api!(@opg_path_value_properties $result context $($properties)*,);
+            $crate::describe_api!(@opg_property_url path $result context { $($path_segment)* });
+            $crate::describe_api!(@opg_path_value_properties $result context $($properties)*,);
 
             $result.paths.push(($crate::models::Path(path), context));
         };)*
     }};
 
     (@opg_property_url $path:ident $result:ident $context:ident { / $($rest:tt)* } $($current:tt)+) => {
-        describe_api!(@opg_path_url $path $result $context $($current)*);
-        describe_api!(@opg_property_url $path $result $context { $($rest)* } )
+        $crate::describe_api!(@opg_path_url $path $result $context $($current)*);
+        $crate::describe_api!(@opg_property_url $path $result $context { $($rest)* } )
     };
     (@opg_property_url $path:ident $result:ident $context:ident {} $($current:tt)+) => {
-        describe_api!(@opg_path_url $path $result $context $($current)*)
+        $crate::describe_api!(@opg_path_url $path $result $context $($current)*)
     };
     (@opg_property_url $path:ident $result:ident $context:ident { $next:tt $($rest:tt)* } $($current:tt)*) => {
-        describe_api!(@opg_property_url $path $result $context { $($rest)* } $($current)* $next )
+        $crate::describe_api!(@opg_property_url $path $result $context { $($rest)* } $($current)* $next )
     };
 
 
     (@opg_path_value_properties $result:ident $context:ident $field:ident: $value:literal, $($other:tt)*) => {
         $context.$field = Some($value.to_owned());
-        describe_api!(@opg_path_value_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_properties $result $context $($other)*)
     };
     (@opg_path_value_properties $result:ident $context:ident parameters: { $($parameters:tt)* }, $($other:tt)*) => {
-        describe_api!(@opg_path_value_parameters $result $context $($parameters)*,);
-        describe_api!(@opg_path_value_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($parameters)*,);
+        $crate::describe_api!(@opg_path_value_properties $result $context $($other)*)
     };
     (@opg_path_value_properties $result:ident $context:ident $method:ident: { $($properties:tt)* }, $($other:tt)*) => {
         let mut operation = $crate::models::Operation::default();
-        describe_api!(@opg_path_value_operation_properties $result operation $($properties)*,);
+        $crate::describe_api!(@opg_path_value_operation_properties $result operation $($properties)*,);
         $context.operations.insert($crate::models::HttpMethod::$method, operation);
 
-        describe_api!(@opg_path_value_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_properties $result $context $($other)*)
     };
     (@opg_path_value_properties $result:ident $context:ident $(,)?) => {};
 
 
-    (@opg_path_value_operation_properties $result:ident $context:ident summary: $value:literal, $($other:tt)*) => {
+    (@opg_path_value_operation_properties $result:ident $context:ident summary: $value:expr, $($other:tt)*) => {
         $context.with_summary($value);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
-    (@opg_path_value_operation_properties $result:ident $context:ident description: $value:literal, $($other:tt)*) => {
+    (@opg_path_value_operation_properties $result:ident $context:ident description: $value:expr, $($other:tt)*) => {
         $context.with_description($value);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
-    (@opg_path_value_operation_properties $result:ident $context:ident deprecated: $value:literal, $($other:tt)*) => {
+    (@opg_path_value_operation_properties $result:ident $context:ident deprecated: $value:expr, $($other:tt)*) => {
         $context.mark_deprecated($value);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident tags: {$($tag:ident),*$(,)?}, $($other:tt)*) => {
         $($context.tags.push(stringify!($tag).to_owned()));*;
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident parameters: { $($parameters:tt)* }, $($other:tt)*) => {
-        describe_api!(@opg_path_value_parameters $result $context $($parameters)*,);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($parameters)*,);
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident callbacks: { $($callbacks:tt)* }, $($other:tt)*) => {
-        describe_api!(@opg_path_value_callbacks $result $context $($callbacks)*,);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_callbacks $result $context $($callbacks)*,);
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident security: { $($security:tt)* }, $($other:tt)*) => {
-        describe_api!(@opg_path_value_security $result $context $($security)*,);
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_security $result $context $($security)*,);
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident body: { $($body:tt)* }, $($other:tt)*) => {
         let mut description = None;
         let mut required = true;
         let schema = $crate::models::ParameterNotSpecified;
-        describe_api!(@opg_path_value_body_properties $result description required schema $($body)*,);
+        $crate::describe_api!(@opg_path_value_body_properties $result description required schema $($body)*,);
         $context.with_request_body($crate::models::RequestBody {
            description: description.or(Some(String::new())),
            required,
            schema, // schema must be specified
         });
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident body: $type:path, $($other:tt)*) => {
         $context.with_request_body($crate::models::RequestBody {
@@ -534,20 +536,20 @@ macro_rules! describe_api {
            required: true,
            schema: $result.components.mention_schema::<$type>(false, &Default::default()),
         });
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident $response:literal$(($description:literal))?: None, $($other:tt)*) => {
-        describe_api!(@opg_path_value_operation_properties $result $context
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context
             $response$(($description))?: { None },
             $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident $response:literal$(($description:literal))?: (), $($other:tt)*) => {
-        describe_api!(@opg_path_value_operation_properties $result $context
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context
             $response$(($description))?: { Some($result.components.mention_schema::<()>(false, &Default::default())) },
             $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident $response:literal$(($description:literal))?: $type:path, $($other:tt)*) => {
-        describe_api!(@opg_path_value_operation_properties $result $context
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context
             $response$(($description))?: { Some($result.components.mention_schema::<$type>(false, &Default::default())) },
             $($other)*)
     };
@@ -562,7 +564,7 @@ macro_rules! describe_api {
             ),
             schema: $($schema)+
         });
-        describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_operation_properties $result $context $($other)*)
     };
     (@opg_path_value_operation_properties $result:ident $context:ident $(,)?) => {};
 
@@ -570,10 +572,10 @@ macro_rules! describe_api {
     (@opg_path_value_security $result:ident $context:ident $($security:tt$([$($role:literal),*])?)&&+, $($other:tt)*) => {
         {
             let mut security = std::collections::BTreeMap::new();
-            $(describe_api!(@opg_path_value_security_item $result security $security$([$($role),*])?));*;
+            $($crate::describe_api!(@opg_path_value_security_item $result security $security$([$($role),*])?));*;
             $context.security.push(security);
         }
-        describe_api!(@opg_path_value_security $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_security $result $context $($other)*)
     };
     (@opg_path_value_security $result:ident $context:ident $(,)*) => {};
 
@@ -588,31 +590,31 @@ macro_rules! describe_api {
 
     (@opg_path_value_body_properties $result:ident $description:ident $required:ident $schema:ident schema: $type:path, $($other:tt)*) => {
         let $schema = $result.components.mention_schema::<$type>(false, &Default::default());
-        describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
+        $crate::describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
     };
     (@opg_path_value_body_properties $result:ident $description:ident $required:ident $schema:ident description: $value:literal, $($other:tt)*) => {
         $description = Some($value.to_owned());
-        describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
+        $crate::describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
     };
     (@opg_path_value_body_properties $result:ident $description:ident $required:ident $schema:ident required: $value:literal, $($other:tt)*) => {
         $required = $value;
-        describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
+        $crate::describe_api!(@opg_path_value_body_properties $result $description $required $schema $($other)*)
     };
     (@opg_path_value_body_properties $result:ident $description:ident $required:ident $schema:ident $(,)?) => {};
 
     (@opg_path_value_callbacks $result:ident $context:ident $callback:literal: { $($operations:tt)* }, $($other:tt)*) => {
         let mut callback_object = CallbackObject::default();
-        describe_api!(@opg_path_value_callbacks_paths $result callback_object $($other)*,);
+        $crate::describe_api!(@opg_path_value_callbacks_paths $result callback_object $($other)*,);
         $context.callbacks.insert($callback.to_owned(), callback_object);
 
-        describe_api!(@opg_path_value_callbacks $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_callbacks $result $context $($other)*)
     };
     (@opg_path_value_callbacks $result:ident $context:ident $callback:ident: { $($paths:tt)* }, $($other:tt)*) => {
         let mut callback_object = CallbackObject::default();
-        describe_api!(@opg_path_value_callbacks_paths $result callback_object $($paths)*,);
+        $crate::describe_api!(@opg_path_value_callbacks_paths $result callback_object $($paths)*,);
         $context.callbacks.insert(stringify!($callback).to_owned(), callback_object);
 
-        describe_api!(@opg_path_value_callbacks $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_callbacks $result $context $($other)*)
     };
     (@opg_path_value_callbacks $result:ident $context:ident $(,)?) => {};
 
@@ -623,14 +625,14 @@ macro_rules! describe_api {
             let mut path = Vec::new();
             let mut context = $crate::models::PathValue::default();
 
-            describe_api!(@opg_property_url path $result context { $($path_segment)* });
-            describe_api!(@opg_path_value_properties $result context $($properties)*,);
+            $crate::describe_api!(@opg_property_url path $result context { $($path_segment)* });
+            $crate::describe_api!(@opg_path_value_properties $result context $($properties)*,);
 
             $context.paths.push(($crate::models::Path(path), context));
         };)*
     };
 
-    (@opg_path_value_parameters $result:ident $context:ident (header $name:literal): { $($properties:tt)* }, $($other:tt)*) => {
+    (@opg_path_value_parameters $result:ident $context:ident (header $name:expr): { $($properties:tt)* }, $($other:tt)*) => {
         {
             let mut parameter = $crate::models::OperationParameter {
                 description: None,
@@ -639,12 +641,12 @@ macro_rules! describe_api {
                 deprecated: false,
                 schema: Some($result.components.mention_schema::<String>(false, &Default::default())),
             };
-            describe_api!(@opg_path_value_parameter_properties $result parameter $($properties)*,);
-            $context.parameters.insert($name.to_owned(), parameter);
+            $crate::describe_api!(@opg_path_value_parameter_properties $result parameter $($properties)*,);
+            $context.parameters.insert(($name).to_string(), parameter);
         }
-        describe_api!(@opg_path_value_parameters $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($other)*)
     };
-    (@opg_path_value_parameters $result:ident $context:ident (header $name:literal), $($other:tt)*) => {
+    (@opg_path_value_parameters $result:ident $context:ident (header $name:expr), $($other:tt)*) => {
         {
             let mut parameter = $crate::models::OperationParameter {
                 description: None,
@@ -653,9 +655,9 @@ macro_rules! describe_api {
                 deprecated: false,
                 schema: Some($result.components.mention_schema::<String>(false, &Default::default())),
             };
-            $context.parameters.insert($name.to_owned(), parameter);
+            $context.parameters.insert(($name).to_string(), parameter);
         }
-        describe_api!(@opg_path_value_parameters $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($other)*)
     };
     (@opg_path_value_parameters $result:ident $context:ident (query $name:ident: $type:path): { $($properties:tt)* }, $($other:tt)*) => {
         {
@@ -666,10 +668,10 @@ macro_rules! describe_api {
                 deprecated: false,
                 schema: Some($result.components.mention_schema::<$type>(false, &Default::default())),
             };
-            describe_api!(@opg_path_value_parameter_properties $result parameter $($properties)*,);
+            $crate::describe_api!(@opg_path_value_parameter_properties $result parameter $($properties)*,);
             $context.parameters.insert(stringify!($name).to_owned(), parameter);
         }
-        describe_api!(@opg_path_value_parameters $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($other)*)
     };
     (@opg_path_value_parameters $result:ident $context:ident (query $name:ident: $type:path), $($other:tt)*) => {
         {
@@ -682,26 +684,26 @@ macro_rules! describe_api {
             };
             $context.parameters.insert(stringify!($name).to_owned(), parameter);
         }
-        describe_api!(@opg_path_value_parameters $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameters $result $context $($other)*)
     };
     (@opg_path_value_parameters $result:ident $context:ident $(,)?) => {};
 
 
-    (@opg_path_value_parameter_properties $result:ident $context:ident description: $value:literal, $($other:tt)*) => {
-        $context.description = Some($value.to_owned());
-        describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
+    (@opg_path_value_parameter_properties $result:ident $context:ident description: $value:expr, $($other:tt)*) => {
+        $context.description = Some(($value).to_string());
+        $crate::describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
     };
-    (@opg_path_value_parameter_properties $result:ident $context:ident required: $value:literal, $($other:tt)*) => {
+    (@opg_path_value_parameter_properties $result:ident $context:ident required: $value:expr, $($other:tt)*) => {
         $context.required = $value;
-        describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
     };
-    (@opg_path_value_parameter_properties $result:ident $context:ident deprecated: $value:literal, $($other:tt)*) => {
+    (@opg_path_value_parameter_properties $result:ident $context:ident deprecated: $value:expr, $($other:tt)*) => {
         $context.deprecated = $value;
-        describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
     };
     (@opg_path_value_parameter_properties $result:ident $context:ident schema: $type:path, $($other:tt)*) => {
         $context.schema = Some($result.components.mention_schema::<$type>(false, &Default::default()));
-        describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
+        $crate::describe_api!(@opg_path_value_parameter_properties $result $context $($other)*)
     };
     (@opg_path_value_parameter_properties $result:ident $context:ident $(,)?) => {};
 
@@ -716,17 +718,17 @@ macro_rules! describe_api {
                 let name = &full_name[full_name.rfind(':').map(|i| i + 1).unwrap_or_default()..];
                 name[..1].to_ascii_lowercase() + &name[1..]
             };
-            describe_api!(@opg_path_insert_url_param $result $context name $current)
+            $crate::describe_api!(@opg_path_insert_url_param $result $context name $current)
         });
     };
     (@opg_path_url $path:ident $result:ident $context:ident {$name:ident: $parameter:path}) => {
         $path.push({
             let name = stringify!($name).to_owned();
-            describe_api!(@opg_path_insert_url_param $result $context name $parameter)
+            $crate::describe_api!(@opg_path_insert_url_param $result $context name $parameter)
         });
     };
     (@opg_path_url $path:ident $result:ident $context:ident $current:literal) => {
-        $path.push(describe_api!(@opg_path_url_element $result $context $current));
+        $path.push($crate::describe_api!(@opg_path_url_element $result $context $current));
     };
 
     (@opg_path_insert_url_param $result:ident $context:ident $name:ident $parameter:path) => {{
