@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::collections::{btree_map::Entry, BTreeMap};
 use std::fmt::Write;
 
@@ -577,7 +578,7 @@ pub trait OpgModel {
     fn get_schema(cx: &mut Components) -> Model;
 
     /// Get name of this type
-    fn type_name() -> Option<&'static str>;
+    fn type_name() -> Option<Cow<'static, str>>;
 
     /// Get schema for this type with context parameters applied
     fn get_schema_with_params(cx: &mut Components, params: &ContextParams) -> Model {
@@ -592,7 +593,7 @@ pub trait OpgModel {
         params: &ContextParams,
     ) -> ModelReference {
         match Self::type_name() {
-            Some(link) if !inline => ModelReference::Link(link.to_owned()),
+            Some(link) if !inline => ModelReference::Link(link.into_owned()),
             _ => ModelReference::Inline(Self::get_schema(cx).apply_params(params)),
         }
     }
@@ -676,6 +677,8 @@ pub struct ModelMergeError;
 pub enum ModelData {
     Single(ModelType),
     OneOf(ModelOneOf),
+    AllOf(ModelAllOf),
+    AnyOf(ModelAnyOf),
 }
 
 impl ModelData {
@@ -684,7 +687,7 @@ impl ModelData {
     pub fn apply_params(self, params: &ContextParams) -> Self {
         match self {
             ModelData::Single(data) => ModelData::Single(data.apply_params(params)),
-            one_of => one_of, // TODO: apply params to oneOf
+            data => data, // TODO: apply params to oneOf, anyOf, and allOf
         }
     }
 
@@ -693,6 +696,8 @@ impl ModelData {
         match self {
             ModelData::Single(single) => single.traverse(cx),
             ModelData::OneOf(one_of) => one_of.traverse(cx),
+            ModelData::AllOf(all_of) => all_of.traverse(cx),
+            ModelData::AnyOf(any_of) => any_of.traverse(cx),
         }
     }
 }
@@ -717,6 +722,46 @@ impl From<ModelOneOf> for ModelData {
     }
 }
 
+/// allOf
+#[derive(Debug, Clone, Default, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub struct ModelAllOf {
+    pub all_of: Vec<ModelReference>,
+}
+
+impl ModelAllOf {
+    /// Check links
+    fn traverse<'a>(&'a self, cx: TraverseContext<'a>) -> Result<(), &'a str> {
+        self.all_of.iter().try_for_each(|item| item.traverse(cx))
+    }
+}
+
+impl From<ModelAllOf> for ModelData {
+    fn from(data: ModelAllOf) -> Self {
+        ModelData::AllOf(data)
+    }
+}
+
+/// anyOf
+#[derive(Debug, Clone, Default, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub struct ModelAnyOf {
+    pub any_of: Vec<ModelReference>,
+}
+
+impl ModelAnyOf {
+    /// Check links
+    fn traverse<'a>(&'a self, cx: TraverseContext<'a>) -> Result<(), &'a str> {
+        self.any_of.iter().try_for_each(|item| item.traverse(cx))
+    }
+}
+
+impl From<ModelAnyOf> for ModelData {
+    fn from(data: ModelAnyOf) -> Self {
+        ModelData::AnyOf(data)
+    }
+}
+
 /// type
 #[derive(Debug, Clone, Serialize)]
 #[serde(rename_all = "camelCase")]
